# QCrypto From Patnam Kannabhiram (A7's Garage)

A Python simulation package for Quantum Cryptography.

## Features
- BB84 Quantum Key Distribution
- E91 Entanglement-based Protocol
- Eavesdropper detection
- Hybrid classical encryption
- No quantum hardware required

## Install
pip install .

## Run Demo
python demo.py
